@@ -22,7 +22,6 @@
 #include <QReadWriteLock>
 
 #include <ktexteditor/document.h>
-#include <ktexteditor/smartinterface.h>
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -94,6 +93,11 @@ void ParseJob::run()
             if (!file->needsUpdate() && file->featuresSatisfied(minimumFeatures())) {
                 kDebug() << "Already up to date" << document().str();
                 setDuChain(file->topContext());
+                if (php() && php()->codeHighlighting()
+                    && ICore::self()->languageController()->backgroundParser()->trackerForUrl(document()))
+                {
+                    php()->codeHighlighting()->highlightDUChain(duChain());
+                }
                 return;
             }
             break;
@@ -102,18 +106,16 @@ void ParseJob::run()
 
     kDebug() << "parsing" << document().str();
 
-    bool readFromDisk = !contentsAvailableFromEditor();
+    KDevelop::ProblemPointer p = readContents();
+    if (p) {
+        //TODO: associate problem with topducontext
+        return abortJob();;
+    }
 
     ParseSession session;
-
-    QString fileName = document().str();
-
-    if (readFromDisk) {
-        session.readFile(fileName);
-    } else {
-        session.setContents(contentsFromEditor());
-        session.setCurrentDocument(document().str());
-    }
+    //TODO: support different charsets
+    session.setContents(QString::fromUtf8(contents().contents));
+    session.setCurrentDocument(document());
 
     // 2) parse
     StartAst* ast = 0;
@@ -181,12 +183,6 @@ void ParseJob::run()
             return abortJob();
         }
 
-        if (editor.smart() && KDevelop::EditorIntegrator::documentForUrl(document())) {
-            if (php() && php()->codeHighlighting()) {
-                php()->codeHighlighting()->highlightDUChain(chain);
-            }
-        }
-
         if (abortRequested()) {
             return abortJob();
         }
@@ -199,46 +195,39 @@ void ParseJob::run()
 
         chain->setFeatures(newFeatures);
         ParsingEnvironmentFilePointer file = chain->parsingEnvironmentFile();
-
-        QFileInfo fileInfo(fileName);
-        QDateTime lastModified = fileInfo.lastModified();
-        if (readFromDisk) {
-            file->setModificationRevision(KDevelop::ModificationRevision(lastModified));
-        } else {
-            file->setModificationRevision(KDevelop::ModificationRevision(lastModified, revisionToken()));
-        }
-
+        file->setModificationRevision(contents().modification);
         DUChain::self()->updateContextEnvironment( chain->topContext(), file.data() );
+
+        if (php() && php()->codeHighlighting()
+            && ICore::self()->languageController()->backgroundParser()->trackerForUrl(document()))
+        {
+            php()->codeHighlighting()->highlightDUChain(chain);
+        }
     } else {
         ReferencedTopDUContext top;
+        DUChainWriteLocker lock;
         {
-            DUChainReadLocker lock(DUChain::lock());
             top = DUChain::self()->chainForDocument(document());
         }
         if (top) {
-            DUChainWriteLocker lock(DUChain::lock());
             ///NOTE: if we clear the imported parent contexts, autocompletion of built-in PHP stuff won't work!
             //top->clearImportedParentContexts();
             top->parsingEnvironmentFile()->clearModificationRevisions();
             top->clearProblems();
         } else {
-            DUChainWriteLocker lock(DUChain::lock());
             ParsingEnvironmentFile *file = new ParsingEnvironmentFile(document());
             /// Indexed string for 'Php', identifies environment files from this language plugin
             static const IndexedString phpLangString("Php");
             file->setLanguage(phpLangString);
-            top = new TopDUContext(document(), SimpleRange(SimpleCursor(0, 0), SimpleCursor(INT_MAX, INT_MAX)), file);
+            top = new TopDUContext(document(), RangeInRevision(0, 0, INT_MAX, INT_MAX), file);
             DUChain::self()->addDocumentChain(top);
         }
-        setDuChain(top);
         foreach(const ProblemPointer &p, session.problems()) {
-            DUChainWriteLocker lock(DUChain::lock());
             top->addProblem(p);
         }
+        setDuChain(top);
         kDebug() << "===Failed===" << document().str();
     }
-
-    cleanupSmartRevision();
 }
 
 void ParseJob::setParentJob(ParseJob *job)
@@ -263,7 +252,7 @@ ProblemPointer ParseJob::createProblem(const QString &description, AstNode* node
     p->setSource(source);
     p->setSeverity(severity);
     p->setDescription(description);
-    p->setFinalLocation(DocumentRange(document().str(), editor->findRange(node).textRange()));
+    p->setFinalLocation(DocumentRange(document(), editor->findRange(node).castToSimpleRange()));
     kDebug() << p->description();
     return p;
 }
